.. Copyright (C) 2016-2019 Maciej Delmanowski <drybjed@gmail.com>
.. Copyright (C) 2016-2019 DebOps <https://debops.org/>
.. SPDX-License-Identifier: GPL-3.0-only

Description
===========

This role allows management of custom file paths, file contents and archives on
remote hosts without the need to create a separate Ansible role. You can use
inventory lists to define what files to copy, what directories should exist on
a remote host, what online resources to download, and so on.
